#include "mainwindow.h"
#include "ui_mainwindow.h"
#include <bcm2835.h>
#include "carteAPIIO.h"
#include "carteAPIAN.h"

#define clk_div BCM2835_I2C_CLOCK_DIVIDER_2500



MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);
    carteAN1 = new carteAPIAN(); // Instanciation d'une carte API AN
    carteAN2 = new carteAPIAN(); // Instanciation d'une seconde carte API AN

    // Paramétrage ComboBox AN
    ui->comboBox_2->addItem("0x14");
    ui->comboBox_2->addItem("0x15");
    ui->comboBox_2->addItem("0x16");
    ui->comboBox_2->addItem("0x17");
    ui->comboBox_2->addItem("0x24");
    ui->comboBox_2->addItem("0x25");
    ui->comboBox_2->addItem("0x26");
    ui->comboBox_2->addItem("0x27");
    ui->comboBox_2->addItem("0x34");

    ui->comboBox_3->addItem("0x14");
    ui->comboBox_3->addItem("0x15");
    ui->comboBox_3->addItem("0x16");
    ui->comboBox_3->addItem("0x17");
    ui->comboBox_3->addItem("0x24");
    ui->comboBox_3->addItem("0x25");
    ui->comboBox_3->addItem("0x26");
    ui->comboBox_3->addItem("0x27");
    ui->comboBox_3->addItem("0x34");

    ui->comboBox_4->addItem("0x14");
    ui->comboBox_4->addItem("0x15");
    ui->comboBox_4->addItem("0x16");
    ui->comboBox_4->addItem("0x17");
    ui->comboBox_4->addItem("0x24");
    ui->comboBox_4->addItem("0x25");
    ui->comboBox_4->addItem("0x26");
    ui->comboBox_4->addItem("0x27");
    ui->comboBox_4->addItem("0x34");

    ui->comboBox_5->addItem("0x14");
    ui->comboBox_5->addItem("0x15");
    ui->comboBox_5->addItem("0x16");
    ui->comboBox_5->addItem("0x17");
    ui->comboBox_5->addItem("0x24");
    ui->comboBox_5->addItem("0x25");
    ui->comboBox_5->addItem("0x26");
    ui->comboBox_5->addItem("0x27");
    ui->comboBox_5->addItem("0x34");

 //   char i2cOut[2];
 //   char i2cIn[22];
    unsigned int slave_address=0x24; // Adresse I2C par défaut (Correspond à float float)
    bcm2835_init();
    bcm2835_i2c_begin();
    bcm2835_i2c_setSlaveAddress(slave_address);
    bcm2835_i2c_setClockDivider(clk_div);

    T1 = new QTimer(this);
    T1->setInterval(500);
    connect(T1,SIGNAL(timeout()),this,SLOT(sltOnTimer()));
    T1->start();
}

MainWindow::~MainWindow()
{
    bcm2835_i2c_end();
    delete ui;
}

void MainWindow::sltOnTimer()
{

    char i2cOut[3];
    char i2cIn[4];
    unsigned int valeur;
    double valeur_tension;
    double valeur_courant;

    // Récupération de l'adresse I2C pour la carte AN1 U2
    bcm2835_i2c_setSlaveAddress(carteAN1->getAdresseU2());

    // Gestion CH0 Carte AN1

    if (carteAN1->CH0_5V())
        {
            i2cOut[0]=0xB0;                 // Valide ADC, mode single, ch0
            i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
            bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
            bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
            bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
            if (i2cIn[0]>191)
                {
                this->ui->label_33->setText("> PE !");  // Tension supérieure à pleine échelle
                this->ui->label_34->setText(" ");       // Effacement de l'unité
                }
            else if (i2cIn[0]<128)
                {
                this->ui->label_33->setText("0V aj"); // OV ajusté si tension très légèrement négative
                this->ui->label_34->setText(" ");      // Effacement de l'unité
                }
            else
                {
                valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                valeur_tension=((double)valeur*5)/65535;    // Calcul de la tension équivalente avec amplification de 2
                QString str = QString::number(valeur_tension,'g',3);
                this->ui->label_33->setText(str);
                this->ui->label_34->setText("V");
                }
        }

    else if (carteAN1->CH0_10V())
        {
            i2cOut[0]=0xB0;                 // Valide ADC, mode single, ch0
            i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
            bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
            bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
            bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
            if (i2cIn[0]>191)
                {
                this->ui->label_33->setText("> PE !");  // Tension supérieure à pleine échelle
                this->ui->label_34->setText(" ");       // Effacement de l'unité
                }
            else if (i2cIn[0]<128)
                {
                this->ui->label_33->setText("0V aj"); // OV ajusté si tension très légèrement négative
                this->ui->label_34->setText(" ");       // Effacement de l'unité
                }
            else
                {
                valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                valeur_tension=((double)valeur*10)/65535;    // Calcul de la tension équivalente avec amplification de 4
                QString str = QString::number(valeur_tension,'g',3);
                this->ui->label_33->setText(str);
                this->ui->label_34->setText("V");
                }
        }

    else if (carteAN1->CH0_4_20mA())
        {
            i2cOut[0]=0xB0;                 // Valide ADC, mode single, ch0
            i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
            bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
            bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
            bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
            if (i2cIn[0]>191)
                {
                this->ui->label_33->setText("> PE !");  // Tension supérieure à pleine échelle
                this->ui->label_34->setText(" ");       // Effacement de l'unité
                }
            else if (i2cIn[0]<128)
                {
                this->ui->label_33->setText("0A aj"); // OV ajusté si tension très légèrement négative
                this->ui->label_34->setText(" ");    // Effacement de l'unité
                }
            else
                {
                valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                valeur_tension=((double)valeur*2.5)/65535;    // Calcul de la tension équivalente
                valeur_courant=valeur_tension*1000/125; // Exprimé en milliampères
                if (valeur_courant<0.1) // Intensité négligeable mais non nulle
                    {
                    this->ui->label_33->setText("0 aj");
                    this->ui->label_34->setText(" ");    // Effacement de l'unité
                    }
                else
                    {
                QString str = QString::number(valeur_courant,'g',3);
                this->ui->label_33->setText(str);
                this->ui->label_34->setText("mA");
                    }
                }
        }

    //------------------------------

        bcm2835_delay(100);             // Délais entre 2 conversions

    //------------------------------
    // Gestion CH1 Carte AN1
    if (carteAN1->CH1_5V())
        {
            i2cOut[0]=0xB8;                 // Valide ADC, mode single, ch0
            i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
            bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
            bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
            bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
            if (i2cIn[0]>191)
                {
                this->ui->label_37->setText("> PE !");  // Tension supérieure à pleine échelle
                this->ui->label_35->setText(" ");       // Effacement de l'unité
                }
            else if (i2cIn[0]<128)
                {
                this->ui->label_37->setText("0V aj"); // OV ajusté si tension très légèrement négative
                this->ui->label_35->setText(" ");       // Effacement de l'unité
                }
            else
                {
                valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                valeur_tension=((double)valeur*5)/65535;    // Calcul de la tension équivalente avec amplification de 2
                QString str = QString::number(valeur_tension,'g',3);
                this->ui->label_37->setText(str);
                this->ui->label_35->setText("V");
                }
        }

    else if (carteAN1->CH1_10V())
        {
            i2cOut[0]=0xB8;                 // Valide ADC, mode single, ch0
            i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
            bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
            bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
            bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
            if (i2cIn[0]>191)
                {
                this->ui->label_37->setText("> PE !");  // Tension supérieure à pleine échelle
                this->ui->label_35->setText(" ");       // Effacement de l'unité
                }
            else if (i2cIn[0]<128)
                {
                this->ui->label_37->setText("0V aj"); // OV ajusté si tension très légèrement négative
                this->ui->label_35->setText(" ");       // Effacement de l'unité
                }
            else
                {
                valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                valeur_tension=((double)valeur*10)/65535;    // Calcul de la tension équivalente avec amplification de 4
                QString str = QString::number(valeur_tension,'g',3);
                this->ui->label_37->setText(str);
                this->ui->label_35->setText("V");
                }
            }

    else if (carteAN1->CH1_4_20mA())
            {
                i2cOut[0]=0xB8;                 // Valide ADC, mode single, ch0
                i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                if (i2cIn[0]>191)
                    {
                    this->ui->label_37->setText("> PE !");  // Tension supérieure à pleine échelle
                    this->ui->label_35->setText(" ");       // Effacement de l'unité
                    }
                else if (i2cIn[0]<128)
                    {
                    this->ui->label_37->setText("0A aj"); // OV ajusté si tension très légèrement négative
                    this->ui->label_35->setText(" ");    // Effacement de l'unité
                    }
                else
                    {
                    valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                    valeur_tension=((double)valeur*2.5)/65535;    // Calcul de la tension équivalente
                    valeur_courant=valeur_tension*1000/125; // Exprimé en milliampères
                    if (valeur_courant<0.1) // Intensité négligeable mais non nulle
                        {
                        this->ui->label_37->setText("0A aj");
                        this->ui->label_35->setText(" ");    // Effacement de l'unité
                        }
                    else
                        {
                    QString str = QString::number(valeur_courant,'g',3);
                    this->ui->label_37->setText(str);
                    this->ui->label_35->setText("mA");
                         }
                    }
            }

        //------------------------------

            bcm2835_delay(100);             // Délais entre 2 conversions

        //------------------------------
        // Gestion CH2 Carte AN1
    if (carteAN1->CH2_5V())
                {
                    i2cOut[0]=0xB1;                 // Valide ADC, mode single, ch0
                    i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                    bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                    bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                    bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                    if (i2cIn[0]>191)
                        {
                        this->ui->label_40->setText("> PE !");  // Tension supérieure à pleine échelle
                        this->ui->label_38->setText(" ");       // Effacement de l'unité
                        }
                    else if (i2cIn[0]<128)
                        {
                        this->ui->label_40->setText("0V aj"); // OV ajusté si tension très légèrement négative
                        this->ui->label_38->setText(" ");       // Effacement de l'unité
                        }
                    else
                        {
                        valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                        valeur_tension=((double)valeur*5)/65535;    // Calcul de la tension équivalente avec amplification de 2
                        QString str = QString::number(valeur_tension,'g',3);
                        this->ui->label_40->setText(str);
                        this->ui->label_38->setText("V");
                        }
                }

    else if (carteAN1->CH2_10V())
                {
                    i2cOut[0]=0xB1;                 // Valide ADC, mode single, ch0
                    i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                    bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                    bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                    bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                    if (i2cIn[0]>191)
                        {
                        this->ui->label_40->setText("> PE !");  // Tension supérieure à pleine échelle
                        this->ui->label_38->setText(" ");       // Effacement de l'unité
                        }
                    else if (i2cIn[0]<128)
                        {
                        this->ui->label_40->setText("0V aj"); // OV ajusté si tension très légèrement négative
                        this->ui->label_38->setText(" ");       // Effacement de l'unité
                        }
                    else
                        {
                        valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                        valeur_tension=((double)valeur*10)/65535;    // Calcul de la tension équivalente avec amplification de 4
                        QString str = QString::number(valeur_tension,'g',3);
                        this->ui->label_40->setText(str);
                        this->ui->label_38->setText("V");
                        }
                }

    else if (carteAN1->CH2_4_20mA())
                {
                    i2cOut[0]=0xB1;                 // Valide ADC, mode single, ch0
                    i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                    bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                    bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                    bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                    if (i2cIn[0]>191)
                        {
                        this->ui->label_40->setText("> PE !");  // Tension supérieure à pleine échelle
                        this->ui->label_38->setText(" ");       // Effacement de l'unité
                        }
                    else if (i2cIn[0]<128)
                        {
                        this->ui->label_40->setText("0A aj"); // OV ajusté si tension très légèrement négative
                        this->ui->label_38->setText(" ");    // Effacement de l'unité
                        }
                    else
                        {
                        valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                        valeur_tension=((double)valeur*2.5)/65535;    // Calcul de la tension équivalente
                        valeur_courant=valeur_tension*1000/125; // Exprimé en milliampères
                        if (valeur_courant<0.1) // Intensité négligeable mais non nulle
                            {
                            this->ui->label_40->setText("0A aj");
                            this->ui->label_38->setText(" ");    // Effacement de l'unité
                            }
                        else
                            {
                        QString str = QString::number(valeur_courant,'g',3);
                        this->ui->label_40->setText(str);
                        this->ui->label_38->setText("mA");
                             }
                        }
                }

    //------------------------------

        bcm2835_delay(100);             // Délais entre 2 conversions

    //------------------------------
    // Gestion CH3 Carte AN1
        if (carteAN1->CH3_5V())
                    {
                        i2cOut[0]=0xB9;                 // Valide ADC, mode single, ch0
                        i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                        bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                        bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                        bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                        if (i2cIn[0]>191)
                            {
                            this->ui->label_43->setText("> PE !");  // Tension supérieure à pleine échelle
                            this->ui->label_41->setText(" ");       // Effacement de l'unité
                            }
                        else if (i2cIn[0]<128)
                            {
                            this->ui->label_43->setText("0V aj"); // OV ajusté si tension très légèrement négative
                            this->ui->label_41->setText(" ");       // Effacement de l'unité
                            }
                        else
                            {
                            valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                            valeur_tension=((double)valeur*5)/65535;    // Calcul de la tension équivalente avec amplification de 2
                            QString str = QString::number(valeur_tension,'g',3);
                            this->ui->label_43->setText(str);
                            this->ui->label_41->setText("V");
                            }
                    }

        else if (carteAN1->CH3_10V())
                    {
                        i2cOut[0]=0xB9;                 // Valide ADC, mode single, ch0
                        i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                        bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                        bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                        bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                        if (i2cIn[0]>191)
                            {
                            this->ui->label_43->setText("> PE !");  // Tension supérieure à pleine échelle
                            this->ui->label_41->setText(" ");       // Effacement de l'unité
                            }
                        else if (i2cIn[0]<128)
                            {
                            this->ui->label_43->setText("0V aj"); // OV ajusté si tension très légèrement négative
                            this->ui->label_41->setText(" ");       // Effacement de l'unité
                            }
                        else
                            {
                            valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                            valeur_tension=((double)valeur*10)/65535;    // Calcul de la tension équivalente avec amplification de 4
                            QString str = QString::number(valeur_tension,'g',3);
                            this->ui->label_43->setText(str);
                            this->ui->label_41->setText("V");
                            }
                    }

        else if (carteAN1->CH3_4_20mA())
                    {
                        i2cOut[0]=0xB9;                 // Valide ADC, mode single, ch0
                        i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                        bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                        bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                        bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                        if (i2cIn[0]>191)
                            {
                            this->ui->label_43->setText("> PE !");  // Tension supérieure à pleine échelle
                            this->ui->label_41->setText(" ");       // Effacement de l'unité
                            }
                        else if (i2cIn[0]<128)
                            {
                            this->ui->label_43->setText("0A aj"); // OV ajusté si tension très légèrement négative
                            this->ui->label_41->setText(" ");    // Effacement de l'unité
                            }
                        else
                            {
                            valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                            valeur_tension=((double)valeur*2.5)/65535;    // Calcul de la tension équivalente
                            valeur_courant=valeur_tension*1000/125; // Exprimé en milliampères
                            if (valeur_courant<0.1) // Intensité négligeable mais non nulle
                                {
                                this->ui->label_43->setText("0A aj");
                                this->ui->label_41->setText(" ");    // Effacement de l'unité
                                }
                            else
                                {
                            QString str = QString::number(valeur_courant,'g',3);
                            this->ui->label_43->setText(str);
                            this->ui->label_41->setText("mA");
                                 }
                            }
                    }

    //------------------------------

          bcm2835_delay(100);             // Délais entre 2 conversions

    //------------------------------


     // Récupération de l'adresse I2C pour la carte AN U3
     bcm2835_i2c_setSlaveAddress(carteAN1->getAdresseU3());

     // Gestion CH4 Carte AN1

     if (carteAN1->CH4_5V())
                    {
                        i2cOut[0]=0xB0;                 // Valide ADC, mode single, ch0
                        i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                        bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                        bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                        bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                        if (i2cIn[0]>191)
                            {
                            this->ui->label_52->setText("> PE !");  // Tension supérieure à pleine échelle
                            this->ui->label_45->setText(" ");       // Effacement de l'unité
                            }
                        else if (i2cIn[0]<128)
                            {
                            this->ui->label_52->setText("0V aj"); // OV ajusté si tension très légèrement négative
                            this->ui->label_45->setText(" ");       // Effacement de l'unité
                            }
                        else
                            {
                            valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                            valeur_tension=((double)valeur*5)/65535;    // Calcul de la tension équivalente avec amplification de 2
                            QString str = QString::number(valeur_tension,'g',3);
                            this->ui->label_52->setText(str);
                            this->ui->label_45->setText("V");
                            }
                    }

     else if (carteAN1->CH4_10V())
                    {
                        i2cOut[0]=0xB0;                 // Valide ADC, mode single, ch0
                        i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                        bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                        bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                        bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                        if (i2cIn[0]>191)
                            {
                            this->ui->label_52->setText("> PE !");  // Tension supérieure à pleine échelle
                            this->ui->label_45->setText(" ");       // Effacement de l'unité
                            }
                        else if (i2cIn[0]<128)
                            {
                            this->ui->label_52->setText("0V aj"); // OV ajusté si tension très légèrement négative
                            this->ui->label_45->setText(" ");       // Effacement de l'unité
                            }
                        else
                            {
                            valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                            valeur_tension=((double)valeur*10)/65535;    // Calcul de la tension équivalente avec amplification de 4
                            QString str = QString::number(valeur_tension,'g',3);
                            this->ui->label_52->setText(str);
                            this->ui->label_45->setText("V");
                            }
                    }

     else if (carteAN1->CH4_4_20mA())
                    {
                        i2cOut[0]=0xB0;                 // Valide ADC, mode single, ch0
                        i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                        bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                        bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                        bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                        if (i2cIn[0]>191)
                            {
                            this->ui->label_52->setText("> PE !");  // Tension supérieure à pleine échelle
                            this->ui->label_45->setText(" ");       // Effacement de l'unité
                            }
                        else if (i2cIn[0]<128)
                            {
                            this->ui->label_52->setText("0A aj"); // OV ajusté si tension très légèrement négative
                            this->ui->label_45->setText(" ");    // Effacement de l'unité
                            }
                        else
                            {
                            valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                            valeur_tension=((double)valeur*2.5)/65535;    // Calcul de la tension équivalente
                            valeur_courant=valeur_tension*1000/125; // Exprimé en milliampères
                            if (valeur_courant<0.1) // Intensité négligeable mais non nulle
                                {
                                this->ui->label_52->setText("0A aj");
                                this->ui->label_45->setText(" ");    // Effacement de l'unité
                                }
                            else
                                {
                            QString str = QString::number(valeur_courant,'g',3);
                            this->ui->label_52->setText(str);
                            this->ui->label_45->setText("mA");
                                }
                            }
                    }

     //------------------------------

     bcm2835_delay(100);             // Délais entre 2 conversions

     //------------------------------
     // Gestion CH5 Carte AN1
     if (carteAN1->CH5_5V())
                        {
                            i2cOut[0]=0xB8;                 // Valide ADC, mode single, ch0
                            i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                            bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                            bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                            bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                            if (i2cIn[0]>191)
                                {
                                this->ui->label_48->setText("> PE !");  // Tension supérieure à pleine échelle
                                this->ui->label_49->setText(" ");       // Effacement de l'unité
                                }
                            else if (i2cIn[0]<128)
                                {
                                this->ui->label_48->setText("0V aj"); // OV ajusté si tension très légèrement négative
                                this->ui->label_49->setText(" ");       // Effacement de l'unité
                                }
                            else
                                {
                                valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                                valeur_tension=((double)valeur*5)/65535;    // Calcul de la tension équivalente avec amplification de 2
                                QString str = QString::number(valeur_tension,'g',3);
                                this->ui->label_48->setText(str);
                                this->ui->label_49->setText("V");
                                }
                        }

     else if (carteAN1->CH5_10V())
                        {
                            i2cOut[0]=0xB8;                 // Valide ADC, mode single, ch0
                            i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                            bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                            bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                            bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                            if (i2cIn[0]>191)
                                {
                                this->ui->label_48->setText("> PE !");  // Tension supérieure à pleine échelle
                                this->ui->label_49->setText(" ");       // Effacement de l'unité
                                }
                            else if (i2cIn[0]<128)
                                {
                                this->ui->label_48->setText("0V aj"); // OV ajusté si tension très légèrement négative
                                this->ui->label_49->setText(" ");       // Effacement de l'unité
                                }
                            else
                                {
                                valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                                valeur_tension=((double)valeur*10)/65535;    // Calcul de la tension équivalente avec amplification de 4
                                QString str = QString::number(valeur_tension,'g',3);
                                this->ui->label_48->setText(str);
                                this->ui->label_49->setText("V");
                                }
                        }

      else if (carteAN1->CH5_4_20mA())
                        {
                            i2cOut[0]=0xB8;                 // Valide ADC, mode single, ch0
                            i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                            bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                            bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                            bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                            if (i2cIn[0]>191)
                                {
                                this->ui->label_48->setText("> PE !");  // Tension supérieure à pleine échelle
                                this->ui->label_49->setText(" ");       // Effacement de l'unité
                                }
                            else if (i2cIn[0]<128)
                                {
                                this->ui->label_48->setText("0A aj"); // OV ajusté si tension très légèrement négative
                                this->ui->label_49->setText(" ");    // Effacement de l'unité
                                }
                            else
                                {
                                valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                                valeur_tension=((double)valeur*2.5)/65535;    // Calcul de la tension équivalente
                                valeur_courant=valeur_tension*1000/125; // Exprimé en milliampères
                                if (valeur_courant<0.1) // Intensité négligeable mais non nulle
                                    {
                                    this->ui->label_48->setText("0A aj");
                                    this->ui->label_49->setText(" ");    // Effacement de l'unité
                                    }
                                else
                                    {
                                QString str = QString::number(valeur_courant,'g',3);
                                this->ui->label_48->setText(str);
                                this->ui->label_49->setText("mA");
                                     }
                                }
                        }

      //------------------------------

      bcm2835_delay(100);             // Délais entre 2 conversions

      //------------------------------
      // Gestion CH6 Carte AN1
      if (carteAN1->CH6_5V())
                            {
                                i2cOut[0]=0xB1;                 // Valide ADC, mode single, ch0
                                i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                                bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                                bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                                bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                                if (i2cIn[0]>191)
                                    {
                                    this->ui->label_54->setText("> PE !");  // Tension supérieure à pleine échelle
                                    this->ui->label_50->setText(" ");       // Effacement de l'unité
                                    }
                                else if (i2cIn[0]<128)
                                    {
                                    this->ui->label_54->setText("0V aj"); // OV ajusté si tension très légèrement négative
                                    this->ui->label_50->setText(" ");       // Effacement de l'unité
                                    }
                                else
                                    {
                                    valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                                    valeur_tension=((double)valeur*5)/65535;    // Calcul de la tension équivalente avec amplification de 2
                                    QString str = QString::number(valeur_tension,'g',3);
                                    this->ui->label_54->setText(str);
                                    this->ui->label_50->setText("V");
                                    }
                            }

      else if (carteAN1->CH6_10V())
                            {
                                i2cOut[0]=0xB1;                 // Valide ADC, mode single, ch0
                                i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                                bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                                bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                                bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                                if (i2cIn[0]>191)
                                    {
                                    this->ui->label_54->setText("> PE !");  // Tension supérieure à pleine échelle
                                    this->ui->label_50->setText(" ");       // Effacement de l'unité
                                    }
                                else if (i2cIn[0]<128)
                                    {
                                    this->ui->label_54->setText("0V aj"); // OV ajusté si tension très légèrement négative
                                    this->ui->label_50->setText(" ");       // Effacement de l'unité
                                    }
                                else
                                    {
                                    valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                                    valeur_tension=((double)valeur*10)/65535;    // Calcul de la tension équivalente avec amplification de 4
                                    QString str = QString::number(valeur_tension,'g',3);
                                    this->ui->label_54->setText(str);
                                    this->ui->label_50->setText("V");
                                    }
                            }

      else if (carteAN1->CH6_4_20mA())
                            {
                                i2cOut[0]=0xB1;                 // Valide ADC, mode single, ch0
                                i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                                bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                                bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                                bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                                if (i2cIn[0]>191)
                                    {
                                    this->ui->label_54->setText("> PE !");  // Tension supérieure à pleine échelle
                                    this->ui->label_50->setText(" ");       // Effacement de l'unité
                                    }
                                else if (i2cIn[0]<128)
                                    {
                                    this->ui->label_54->setText("0A aj"); // OV ajusté si tension très légèrement négative
                                    this->ui->label_50->setText(" ");    // Effacement de l'unité
                                    }
                                else
                                    {
                                    valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                                    valeur_tension=((double)valeur*2.5)/65535;    // Calcul de la tension équivalente
                                    valeur_courant=valeur_tension*1000/125; // Exprimé en milliampères
                                    if (valeur_courant<0.1) // Intensité négligeable mais non nulle
                                        {
                                        this->ui->label_54->setText("0A aj");
                                        this->ui->label_50->setText(" ");    // Effacement de l'unité
                                        }
                                    else
                                        {
                                    QString str = QString::number(valeur_courant,'g',3);
                                    this->ui->label_54->setText(str);
                                    this->ui->label_50->setText("mA");
                                         }
                                    }
                            }

    //------------------------------

    bcm2835_delay(100);             // Délais entre 2 conversions

    //------------------------------
    // Gestion CH7 Carte AN1
    if (carteAN1->CH7_5V())
                            {
                                i2cOut[0]=0xB9;                 // Valide ADC, mode single, ch0
                                i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                                bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                                bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                                bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                                if (i2cIn[0]>191)
                                    {
                                    this->ui->label_44->setText("> PE !");  // Tension supérieure à pleine échelle
                                    this->ui->label_47->setText(" ");       // Effacement de l'unité
                                    }
                                else if (i2cIn[0]<128)
                                    {
                                    this->ui->label_44->setText("0V aj"); // OV ajusté si tension très légèrement négative
                                    this->ui->label_47->setText(" ");       // Effacement de l'unité
                                    }
                                else
                                    {
                                    valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                                    valeur_tension=((double)valeur*5)/65535;    // Calcul de la tension équivalente avec amplification de 2
                                    QString str = QString::number(valeur_tension,'g',3);
                                    this->ui->label_44->setText(str);
                                    this->ui->label_47->setText("V");
                                    }
                            }
    else if (carteAN1->CH7_10V())
                            {
                                i2cOut[0]=0xB9;                 // Valide ADC, mode single, ch0
                                i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                                bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                                bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                                bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                                if (i2cIn[0]>191)
                                    {
                                    this->ui->label_44->setText("> PE !");  // Tension supérieure à pleine échelle
                                    this->ui->label_47->setText(" ");       // Effacement de l'unité
                                    }
                                else if (i2cIn[0]<128)
                                    {
                                    this->ui->label_44->setText("0V aj"); // OV ajusté si tension très légèrement négative
                                    this->ui->label_47->setText(" ");       // Effacement de l'unité
                                    }
                                else
                                    {
                                    valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                                    valeur_tension=((double)valeur*10)/65535;    // Calcul de la tension équivalente avec amplification de 4
                                    QString str = QString::number(valeur_tension,'g',3);
                                    this->ui->label_44->setText(str);
                                    this->ui->label_47->setText("V");
                                    }
                            }
    else if (carteAN1->CH7_4_20mA())
                            {
                                i2cOut[0]=0xB9;                 // Valide ADC, mode single, ch0
                                i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                                bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                                bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                                bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                                if (i2cIn[0]>191)
                                    {
                                    this->ui->label_44->setText("> PE !");  // Tension supérieure à pleine échelle
                                    this->ui->label_47->setText(" ");       // Effacement de l'unité
                                    }
                                 else if (i2cIn[0]<128)
                                    {
                                    this->ui->label_44->setText("0A aj"); // OV ajusté si tension très légèrement négative
                                    this->ui->label_47->setText(" ");    // Effacement de l'unité
                                    }
                                else
                                    {
                                    valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                                    valeur_tension=((double)valeur*2.5)/65535;    // Calcul de la tension équivalente
                                    valeur_courant=valeur_tension*1000/125; // Exprimé en milliampères
                                    if (valeur_courant<0.1) // Intensité négligeable mais non nulle
                                        {
                                        this->ui->label_44->setText("0A aj");
                                        this->ui->label_47->setText(" ");    // Effacement de l'unité
                                        }
                                    else
                                        {
                                        QString str = QString::number(valeur_courant,'g',3);
                                        this->ui->label_44->setText(str);
                                        this->ui->label_47->setText("mA");
                                         }
                                    }
                            }

//**************************************** Gestion Carte 2

    // Récupération de l'adresse I2C pour la carte AN2 U2
    bcm2835_i2c_setSlaveAddress(carteAN2->getAdresseU2());

    // Gestion CH0 Carte AN2

    if (carteAN2->CH0_5V())
        {
            i2cOut[0]=0xB0;                 // Valide ADC, mode single, ch0
            i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
            bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
            bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
            bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
            if (i2cIn[0]>191)
                {
                this->ui->label_65->setText("> PE !");  // Tension supérieure à pleine échelle
                this->ui->label_70->setText(" ");       // Effacement de l'unité
                }
            else if (i2cIn[0]<128)
                {
                this->ui->label_65->setText("0V aj"); // OV ajusté si tension très légèrement négative
                this->ui->label_70->setText(" ");      // Effacement de l'unité
                }
            else
                {
                valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                valeur_tension=((double)valeur*5)/65535;    // Calcul de la tension équivalente avec amplification de 2
                QString str = QString::number(valeur_tension,'g',3);
                this->ui->label_65->setText(str);
                this->ui->label_70->setText("V");
                }
        }

    else if (carteAN2->CH0_10V())
        {
            i2cOut[0]=0xB0;                 // Valide ADC, mode single, ch0
            i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
            bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
            bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
            bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
            if (i2cIn[0]>191)
                {
                this->ui->label_65->setText("> PE !");  // Tension supérieure à pleine échelle
                this->ui->label_70->setText(" ");       // Effacement de l'unité
                }
            else if (i2cIn[0]<128)
                {
                this->ui->label_65->setText("0V aj"); // OV ajusté si tension très légèrement négative
                this->ui->label_70->setText(" ");       // Effacement de l'unité
                }
            else
                {
                valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                valeur_tension=((double)valeur*10)/65535;    // Calcul de la tension équivalente avec amplification de 4
                QString str = QString::number(valeur_tension,'g',3);
                this->ui->label_65->setText(str);
                this->ui->label_70->setText("V");
                }
        }

    else if (carteAN2->CH0_4_20mA())
        {
            i2cOut[0]=0xB0;                 // Valide ADC, mode single, ch0
            i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
            bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
            bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
            bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
            if (i2cIn[0]>191)
                {
                this->ui->label_65->setText("> PE !");  // Tension supérieure à pleine échelle
                this->ui->label_70->setText(" ");       // Effacement de l'unité
                }
            else if (i2cIn[0]<128)
                {
                this->ui->label_65->setText("0A aj"); // OV ajusté si tension très légèrement négative
                this->ui->label_70->setText(" ");    // Effacement de l'unité
                }
            else
                {
                valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                valeur_tension=((double)valeur*2.5)/65535;    // Calcul de la tension équivalente
                valeur_courant=valeur_tension*1000/125; // Exprimé en milliampères
                if (valeur_courant<0.1) // Intensité négligeable mais non nulle
                    {
                    this->ui->label_65->setText("0 aj");
                    this->ui->label_70->setText(" ");    // Effacement de l'unité
                    }
                else
                    {
                QString str = QString::number(valeur_courant,'g',3);
                this->ui->label_65->setText(str);
                this->ui->label_70->setText("mA");
                    }
                }
        }

    //------------------------------

        bcm2835_delay(100);             // Délais entre 2 conversions

    //------------------------------
    // Gestion CH1 Carte AN2
    if (carteAN2->CH1_5V())
        {
            i2cOut[0]=0xB8;                 // Valide ADC, mode single, ch0
            i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
            bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
            bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
            bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
            if (i2cIn[0]>191)
                {
                this->ui->label_74->setText("> PE !");  // Tension supérieure à pleine échelle
                this->ui->label_76->setText(" ");       // Effacement de l'unité
                }
            else if (i2cIn[0]<128)
                {
                this->ui->label_74->setText("0V aj"); // OV ajusté si tension très légèrement négative
                this->ui->label_76->setText(" ");       // Effacement de l'unité
                }
            else
                {
                valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                valeur_tension=((double)valeur*5)/65535;    // Calcul de la tension équivalente avec amplification de 2
                QString str = QString::number(valeur_tension,'g',3);
                this->ui->label_74->setText(str);
                this->ui->label_76->setText("V");
                }
        }

    else if (carteAN2->CH1_10V())
        {
            i2cOut[0]=0xB8;                 // Valide ADC, mode single, ch0
            i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
            bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
            bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
            bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
            if (i2cIn[0]>191)
                {
                this->ui->label_74->setText("> PE !");  // Tension supérieure à pleine échelle
                this->ui->label_76->setText(" ");       // Effacement de l'unité
                }
            else if (i2cIn[0]<128)
                {
                this->ui->label_74->setText("0V aj"); // OV ajusté si tension très légèrement négative
                this->ui->label_76->setText(" ");       // Effacement de l'unité
                }
            else
                {
                valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                valeur_tension=((double)valeur*10)/65535;    // Calcul de la tension équivalente avec amplification de 4
                QString str = QString::number(valeur_tension,'g',3);
                this->ui->label_74->setText(str);
                this->ui->label_76->setText("V");
                }
            }

    else if (carteAN2->CH1_4_20mA())
            {
                i2cOut[0]=0xB8;                 // Valide ADC, mode single, ch0
                i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                if (i2cIn[0]>191)
                    {
                    this->ui->label_74->setText("> PE !");  // Tension supérieure à pleine échelle
                    this->ui->label_76->setText(" ");       // Effacement de l'unité
                    }
                else if (i2cIn[0]<128)
                    {
                    this->ui->label_74->setText("0A aj"); // OV ajusté si tension très légèrement négative
                    this->ui->label_76->setText(" ");    // Effacement de l'unité
                    }
                else
                    {
                    valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                    valeur_tension=((double)valeur*2.5)/65535;    // Calcul de la tension équivalente
                    valeur_courant=valeur_tension*1000/125; // Exprimé en milliampères
                    if (valeur_courant<0.1) // Intensité négligeable mais non nulle
                        {
                        this->ui->label_74->setText("0A aj");
                        this->ui->label_76->setText(" ");    // Effacement de l'unité
                        }
                    else
                        {
                    QString str = QString::number(valeur_courant,'g',3);
                    this->ui->label_74->setText(str);
                    this->ui->label_76->setText("mA");
                         }
                    }
            }

        //------------------------------

            bcm2835_delay(100);             // Délais entre 2 conversions

        //------------------------------
        // Gestion CH2 Carte AN2
    if (carteAN2->CH2_5V())
                {
                    i2cOut[0]=0xB1;                 // Valide ADC, mode single, ch0
                    i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                    bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                    bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                    bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                    if (i2cIn[0]>191)
                        {
                        this->ui->label_56->setText("> PE !");  // Tension supérieure à pleine échelle
                        this->ui->label_82->setText(" ");       // Effacement de l'unité
                        }
                    else if (i2cIn[0]<128)
                        {
                        this->ui->label_56->setText("0V aj"); // OV ajusté si tension très légèrement négative
                        this->ui->label_82->setText(" ");       // Effacement de l'unité
                        }
                    else
                        {
                        valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                        valeur_tension=((double)valeur*5)/65535;    // Calcul de la tension équivalente avec amplification de 2
                        QString str = QString::number(valeur_tension,'g',3);
                        this->ui->label_56->setText(str);
                        this->ui->label_82->setText("V");
                        }
                }

    else if (carteAN2->CH2_10V())
                {
                    i2cOut[0]=0xB1;                 // Valide ADC, mode single, ch0
                    i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                    bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                    bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                    bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                    if (i2cIn[0]>191)
                        {
                        this->ui->label_56->setText("> PE !");  // Tension supérieure à pleine échelle
                        this->ui->label_82->setText(" ");       // Effacement de l'unité
                        }
                    else if (i2cIn[0]<128)
                        {
                        this->ui->label_56->setText("0V aj"); // OV ajusté si tension très légèrement négative
                        this->ui->label_82->setText(" ");       // Effacement de l'unité
                        }
                    else
                        {
                        valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                        valeur_tension=((double)valeur*10)/65535;    // Calcul de la tension équivalente avec amplification de 4
                        QString str = QString::number(valeur_tension,'g',3);
                        this->ui->label_56->setText(str);
                        this->ui->label_82->setText("V");
                        }
                }

    else if (carteAN2->CH2_4_20mA())
                {
                    i2cOut[0]=0xB1;                 // Valide ADC, mode single, ch0
                    i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                    bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                    bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                    bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                    if (i2cIn[0]>191)
                        {
                        this->ui->label_56->setText("> PE !");  // Tension supérieure à pleine échelle
                        this->ui->label_82->setText(" ");       // Effacement de l'unité
                        }
                    else if (i2cIn[0]<128)
                        {
                        this->ui->label_56->setText("0A aj"); // OV ajusté si tension très légèrement négative
                        this->ui->label_82->setText(" ");    // Effacement de l'unité
                        }
                    else
                        {
                        valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                        valeur_tension=((double)valeur*2.5)/65535;    // Calcul de la tension équivalente
                        valeur_courant=valeur_tension*1000/125; // Exprimé en milliampères
                        if (valeur_courant<0.1) // Intensité négligeable mais non nulle
                            {
                            this->ui->label_56->setText("0A aj");
                            this->ui->label_82->setText(" ");    // Effacement de l'unité
                            }
                        else
                            {
                        QString str = QString::number(valeur_courant,'g',3);
                        this->ui->label_56->setText(str);
                        this->ui->label_82->setText("mA");
                             }
                        }
                }

    //------------------------------

        bcm2835_delay(100);             // Délais entre 2 conversions

    //------------------------------
    // Gestion CH3 Carte AN2
        if (carteAN2->CH3_5V())
                    {
                        i2cOut[0]=0xB9;                 // Valide ADC, mode single, ch0
                        i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                        bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                        bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                        bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                        if (i2cIn[0]>191)
                            {
                            this->ui->label_71->setText("> PE !");  // Tension supérieure à pleine échelle
                            this->ui->label_68->setText(" ");       // Effacement de l'unité
                            }
                        else if (i2cIn[0]<128)
                            {
                            this->ui->label_71->setText("0V aj"); // OV ajusté si tension très légèrement négative
                            this->ui->label_68->setText(" ");       // Effacement de l'unité
                            }
                        else
                            {
                            valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                            valeur_tension=((double)valeur*5)/65535;    // Calcul de la tension équivalente avec amplification de 2
                            QString str = QString::number(valeur_tension,'g',3);
                            this->ui->label_71->setText(str);
                            this->ui->label_68->setText("V");
                            }
                    }

        else if (carteAN2->CH3_10V())
                    {
                        i2cOut[0]=0xB9;                 // Valide ADC, mode single, ch0
                        i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                        bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                        bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                        bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                        if (i2cIn[0]>191)
                            {
                            this->ui->label_71->setText("> PE !");  // Tension supérieure à pleine échelle
                            this->ui->label_68->setText(" ");       // Effacement de l'unité
                            }
                        else if (i2cIn[0]<128)
                            {
                            this->ui->label_71->setText("0V aj"); // OV ajusté si tension très légèrement négative
                            this->ui->label_68->setText(" ");       // Effacement de l'unité
                            }
                        else
                            {
                            valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                            valeur_tension=((double)valeur*10)/65535;    // Calcul de la tension équivalente avec amplification de 4
                            QString str = QString::number(valeur_tension,'g',3);
                            this->ui->label_71->setText(str);
                            this->ui->label_68->setText("V");
                            }
                    }

        else if (carteAN2->CH3_4_20mA())
                    {
                        i2cOut[0]=0xB9;                 // Valide ADC, mode single, ch0
                        i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                        bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                        bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                        bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                        if (i2cIn[0]>191)
                            {
                            this->ui->label_71->setText("> PE !");  // Tension supérieure à pleine échelle
                            this->ui->label_68->setText(" ");       // Effacement de l'unité
                            }
                        else if (i2cIn[0]<128)
                            {
                            this->ui->label_71->setText("0A aj"); // OV ajusté si tension très légèrement négative
                            this->ui->label_68->setText(" ");    // Effacement de l'unité
                            }
                        else
                            {
                            valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                            valeur_tension=((double)valeur*2.5)/65535;    // Calcul de la tension équivalente
                            valeur_courant=valeur_tension*1000/125; // Exprimé en milliampères
                            if (valeur_courant<0.1) // Intensité négligeable mais non nulle
                                {
                                this->ui->label_71->setText("0A aj");
                                this->ui->label_68->setText(" ");    // Effacement de l'unité
                                }
                            else
                                {
                            QString str = QString::number(valeur_courant,'g',3);
                            this->ui->label_71->setText(str);
                            this->ui->label_68->setText("mA");
                                 }
                            }
                    }

    //------------------------------

          bcm2835_delay(100);             // Délais entre 2 conversions

    //------------------------------


     // Récupération de l'adresse I2C pour la carte AN2 U3
     bcm2835_i2c_setSlaveAddress(carteAN2->getAdresseU3());

     // Gestion CH4 Carte AN2

     if (carteAN2->CH4_5V())
                    {
                        i2cOut[0]=0xB0;                 // Valide ADC, mode single, ch0
                        i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                        bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                        bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                        bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                        if (i2cIn[0]>191)
                            {
                            this->ui->label_63->setText("> PE !");  // Tension supérieure à pleine échelle
                            this->ui->label_61->setText(" ");       // Effacement de l'unité
                            }
                        else if (i2cIn[0]<128)
                            {
                            this->ui->label_63->setText("0V aj"); // OV ajusté si tension très légèrement négative
                            this->ui->label_61->setText(" ");       // Effacement de l'unité
                            }
                        else
                            {
                            valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                            valeur_tension=((double)valeur*5)/65535;    // Calcul de la tension équivalente avec amplification de 2
                            QString str = QString::number(valeur_tension,'g',3);
                            this->ui->label_63->setText(str);
                            this->ui->label_61->setText("V");
                            }
                    }

     else if (carteAN2->CH4_10V())
                    {
                        i2cOut[0]=0xB0;                 // Valide ADC, mode single, ch0
                        i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                        bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                        bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                        bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                        if (i2cIn[0]>191)
                            {
                            this->ui->label_63->setText("> PE !");  // Tension supérieure à pleine échelle
                            this->ui->label_61->setText(" ");       // Effacement de l'unité
                            }
                        else if (i2cIn[0]<128)
                            {
                            this->ui->label_63->setText("0V aj"); // OV ajusté si tension très légèrement négative
                            this->ui->label_61->setText(" ");       // Effacement de l'unité
                            }
                        else
                            {
                            valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                            valeur_tension=((double)valeur*10)/65535;    // Calcul de la tension équivalente avec amplification de 4
                            QString str = QString::number(valeur_tension,'g',3);
                            this->ui->label_63->setText(str);
                            this->ui->label_61->setText("V");
                            }
                    }

     else if (carteAN2->CH4_4_20mA())
                    {
                        i2cOut[0]=0xB0;                 // Valide ADC, mode single, ch0
                        i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                        bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                        bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                        bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                        if (i2cIn[0]>191)
                            {
                            this->ui->label_63->setText("> PE !");  // Tension supérieure à pleine échelle
                            this->ui->label_61->setText(" ");       // Effacement de l'unité
                            }
                        else if (i2cIn[0]<128)
                            {
                            this->ui->label_63->setText("0A aj"); // OV ajusté si tension très légèrement négative
                            this->ui->label_61->setText(" ");    // Effacement de l'unité
                            }
                        else
                            {
                            valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                            valeur_tension=((double)valeur*2.5)/65535;    // Calcul de la tension équivalente
                            valeur_courant=valeur_tension*1000/125; // Exprimé en milliampères
                            if (valeur_courant<0.1) // Intensité négligeable mais non nulle
                                {
                                this->ui->label_63->setText("0A aj");
                                this->ui->label_61->setText(" ");    // Effacement de l'unité
                                }
                            else
                                {
                            QString str = QString::number(valeur_courant,'g',3);
                            this->ui->label_63->setText(str);
                            this->ui->label_61->setText("mA");
                                }
                            }
                    }

     //------------------------------

     bcm2835_delay(100);             // Délais entre 2 conversions

     //------------------------------
     // Gestion CH5 Carte AN2
     if (carteAN2->CH5_5V())
                        {
                            i2cOut[0]=0xB8;                 // Valide ADC, mode single, ch0
                            i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                            bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                            bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                            bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                            if (i2cIn[0]>191)
                                {
                                this->ui->label_69->setText("> PE !");  // Tension supérieure à pleine échelle
                                this->ui->label_81->setText(" ");       // Effacement de l'unité
                                }
                            else if (i2cIn[0]<128)
                                {
                                this->ui->label_69->setText("0V aj"); // OV ajusté si tension très légèrement négative
                                this->ui->label_81->setText(" ");       // Effacement de l'unité
                                }
                            else
                                {
                                valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                                valeur_tension=((double)valeur*5)/65535;    // Calcul de la tension équivalente avec amplification de 2
                                QString str = QString::number(valeur_tension,'g',3);
                                this->ui->label_69->setText(str);
                                this->ui->label_81->setText("V");
                                }
                        }

     else if (carteAN2->CH5_10V())
                        {
                            i2cOut[0]=0xB8;                 // Valide ADC, mode single, ch0
                            i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                            bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                            bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                            bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                            if (i2cIn[0]>191)
                                {
                                this->ui->label_69->setText("> PE !");  // Tension supérieure à pleine échelle
                                this->ui->label_81->setText(" ");       // Effacement de l'unité
                                }
                            else if (i2cIn[0]<128)
                                {
                                this->ui->label_69->setText("0V aj"); // OV ajusté si tension très légèrement négative
                                this->ui->label_81->setText(" ");       // Effacement de l'unité
                                }
                            else
                                {
                                valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                                valeur_tension=((double)valeur*10)/65535;    // Calcul de la tension équivalente avec amplification de 4
                                QString str = QString::number(valeur_tension,'g',3);
                                this->ui->label_69->setText(str);
                                this->ui->label_81->setText("V");
                                }
                        }

      else if (carteAN2->CH5_4_20mA())
                        {
                            i2cOut[0]=0xB8;                 // Valide ADC, mode single, ch0
                            i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                            bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                            bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                            bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                            if (i2cIn[0]>191)
                                {
                                this->ui->label_69->setText("> PE !");  // Tension supérieure à pleine échelle
                                this->ui->label_81->setText(" ");       // Effacement de l'unité
                                }
                            else if (i2cIn[0]<128)
                                {
                                this->ui->label_69->setText("0A aj"); // OV ajusté si tension très légèrement négative
                                this->ui->label_81->setText(" ");    // Effacement de l'unité
                                }
                            else
                                {
                                valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                                valeur_tension=((double)valeur*2.5)/65535;    // Calcul de la tension équivalente
                                valeur_courant=valeur_tension*1000/125; // Exprimé en milliampères
                                if (valeur_courant<0.1) // Intensité négligeable mais non nulle
                                    {
                                    this->ui->label_69->setText("0A aj");
                                    this->ui->label_81->setText(" ");    // Effacement de l'unité
                                    }
                                else
                                    {
                                QString str = QString::number(valeur_courant,'g',3);
                                this->ui->label_69->setText(str);
                                this->ui->label_81->setText("mA");
                                     }
                                }
                        }

      //------------------------------

      bcm2835_delay(100);             // Délais entre 2 conversions

      //------------------------------
      // Gestion CH6 Carte AN2
      if (carteAN2->CH6_5V())
                            {
                                i2cOut[0]=0xB1;                 // Valide ADC, mode single, ch0
                                i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                                bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                                bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                                bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                                if (i2cIn[0]>191)
                                    {
                                    this->ui->label_64->setText("> PE !");  // Tension supérieure à pleine échelle
                                    this->ui->label_75->setText(" ");       // Effacement de l'unité
                                    }
                                else if (i2cIn[0]<128)
                                    {
                                    this->ui->label_64->setText("0V aj"); // OV ajusté si tension très légèrement négative
                                    this->ui->label_75->setText(" ");       // Effacement de l'unité
                                    }
                                else
                                    {
                                    valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                                    valeur_tension=((double)valeur*5)/65535;    // Calcul de la tension équivalente avec amplification de 2
                                    QString str = QString::number(valeur_tension,'g',3);
                                    this->ui->label_64->setText(str);
                                    this->ui->label_75->setText("V");
                                    }
                            }

      else if (carteAN2->CH6_10V())
                            {
                                i2cOut[0]=0xB1;                 // Valide ADC, mode single, ch0
                                i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                                bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                                bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                                bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                                if (i2cIn[0]>191)
                                    {
                                    this->ui->label_64->setText("> PE !");  // Tension supérieure à pleine échelle
                                    this->ui->label_75->setText(" ");       // Effacement de l'unité
                                    }
                                else if (i2cIn[0]<128)
                                    {
                                    this->ui->label_64->setText("0V aj"); // OV ajusté si tension très légèrement négative
                                    this->ui->label_75->setText(" ");       // Effacement de l'unité
                                    }
                                else
                                    {
                                    valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                                    valeur_tension=((double)valeur*10)/65535;    // Calcul de la tension équivalente avec amplification de 4
                                    QString str = QString::number(valeur_tension,'g',3);
                                    this->ui->label_64->setText(str);
                                    this->ui->label_75->setText("V");
                                    }
                            }

      else if (carteAN2->CH6_4_20mA())
                            {
                                i2cOut[0]=0xB1;                 // Valide ADC, mode single, ch0
                                i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                                bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                                bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                                bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                                if (i2cIn[0]>191)
                                    {
                                    this->ui->label_64->setText("> PE !");  // Tension supérieure à pleine échelle
                                    this->ui->label_75->setText(" ");       // Effacement de l'unité
                                    }
                                else if (i2cIn[0]<128)
                                    {
                                    this->ui->label_64->setText("0A aj"); // OV ajusté si tension très légèrement négative
                                    this->ui->label_75->setText(" ");    // Effacement de l'unité
                                    }
                                else
                                    {
                                    valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                                    valeur_tension=((double)valeur*2.5)/65535;    // Calcul de la tension équivalente
                                    valeur_courant=valeur_tension*1000/125; // Exprimé en milliampères
                                    if (valeur_courant<0.1) // Intensité négligeable mais non nulle
                                        {
                                        this->ui->label_64->setText("0A aj");
                                        this->ui->label_75->setText(" ");    // Effacement de l'unité
                                        }
                                    else
                                        {
                                    QString str = QString::number(valeur_courant,'g',3);
                                    this->ui->label_64->setText(str);
                                    this->ui->label_75->setText("mA");
                                         }
                                    }
                            }

    //------------------------------

    bcm2835_delay(100);             // Délais entre 2 conversions

    //------------------------------
    // Gestion CH7 Carte AN2
    if (carteAN2->CH7_5V())
                            {
                                i2cOut[0]=0xB9;                 // Valide ADC, mode single, ch0
                                i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                                bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                                bcm2835_delay(100);             //4 Tempo supérieure à celle de la conversion
                                bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                                if (i2cIn[0]>191)
                                    {
                                    this->ui->label_60->setText("> PE !");  // Tension supérieure à pleine échelle
                                    this->ui->label_78->setText(" ");       // Effacement de l'unité
                                    }
                                else if (i2cIn[0]<128)
                                    {
                                    this->ui->label_60->setText("0V aj"); // OV ajusté si tension très légèrement négative
                                    this->ui->label_78->setText(" ");       // Effacement de l'unité
                                    }
                                else
                                    {
                                    valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                                    valeur_tension=((double)valeur*5)/65535;    // Calcul de la tension équivalente avec amplification de 2
                                    QString str = QString::number(valeur_tension,'g',3);
                                    this->ui->label_60->setText(str);
                                    this->ui->label_78->setText("V");
                                    }
                            }
    else if (carteAN2->CH7_10V())
                            {
                                i2cOut[0]=0xB9;                 // Valide ADC, mode single, ch0
                                i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                                bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                                bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                                bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                                if (i2cIn[0]>191)
                                    {
                                    this->ui->label_60->setText("> PE !");  // Tension supérieure à pleine échelle
                                    this->ui->label_78->setText(" ");       // Effacement de l'unité
                                    }
                                else if (i2cIn[0]<128)
                                    {
                                    this->ui->label_60->setText("0V aj"); // OV ajusté si tension très légèrement négative
                                    this->ui->label_78->setText(" ");       // Effacement de l'unité
                                    }
                                else
                                    {
                                    valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                                    valeur_tension=((double)valeur*10)/65535;    // Calcul de la tension équivalente avec amplification de 4
                                    QString str = QString::number(valeur_tension,'g',3);
                                    this->ui->label_60->setText(str);
                                    this->ui->label_78->setText("V");
                                    }
                            }
    else if (carteAN2->CH7_4_20mA())
                            {
                                i2cOut[0]=0xB9;                 // Valide ADC, mode single, ch0
                                i2cOut[1]=0x88;                 // Entrée externe, gain 1, speed2
                                bcm2835_i2c_write(i2cOut, 2); 	// Ecriture dans l'ADC
                                bcm2835_delay(100);             // Tempo supérieure à celle de la conversion
                                bcm2835_i2c_read(i2cIn, 3); 	// Lecture des 3 octets du résultat
                                if (i2cIn[0]>191)
                                    {
                                    this->ui->label_60->setText("> PE !");  // Tension supérieure à pleine échelle
                                    this->ui->label_78->setText(" ");       // Effacement de l'unité
                                    }
                                 else if (i2cIn[0]<128)
                                    {
                                    this->ui->label_60->setText("0A aj"); // OV ajusté si tension très légèrement négative
                                    this->ui->label_78->setText(" ");    // Effacement de l'unité
                                    }
                                else
                                    {
                                    valeur=((i2cIn[2]>>6) + (4*i2cIn[1]) + 1024*(i2cIn[0]&0b00111111)); // Mise en forme et calcul de la valeur reçue
                                    valeur_tension=((double)valeur*2.5)/65535;    // Calcul de la tension équivalente
                                    valeur_courant=valeur_tension*1000/125; // Exprimé en milliampères
                                    if (valeur_courant<0.1) // Intensité négligeable mais non nulle
                                        {
                                        this->ui->label_60->setText("0A aj");
                                        this->ui->label_78->setText(" ");    // Effacement de l'unité
                                        }
                                    else
                                        {
                                        QString str = QString::number(valeur_courant,'g',3);
                                        this->ui->label_60->setText(str);
                                        this->ui->label_78->setText("mA");
                                         }
                                    }
                            }





}


void MainWindow::on_comboBox_2_activated(int index)
{
    // Affectation de l'adresse I2C carte AN1 Circuit U2
    if (index==0) carteAN1->setAdresseU2(0x14);
    if (index==1) carteAN1->setAdresseU2(0x15);
    if (index==2) carteAN1->setAdresseU2(0x16);
    if (index==3) carteAN1->setAdresseU2(0x17);
    if (index==4) carteAN1->setAdresseU2(0x24);
    if (index==5) carteAN1->setAdresseU2(0x25);
    if (index==6) carteAN1->setAdresseU2(0x26);
    if (index==7) carteAN1->setAdresseU2(0x27);
    if (index==8) carteAN1->setAdresseU2(0x34);
}

void MainWindow::on_comboBox_3_activated(int index)
{
    // Affectation de l'adresse I2C carte AN1 Circuit U3
    if (index==0) carteAN1->setAdresseU3(0x14);
    if (index==1) carteAN1->setAdresseU3(0x15);
    if (index==2) carteAN1->setAdresseU3(0x16);
    if (index==3) carteAN1->setAdresseU3(0x17);
    if (index==4) carteAN1->setAdresseU3(0x24);
    if (index==5) carteAN1->setAdresseU3(0x25);
    if (index==6) carteAN1->setAdresseU3(0x26);
    if (index==7) carteAN1->setAdresseU3(0x27);
    if (index==8) carteAN1->setAdresseU3(0x34);
}

void MainWindow::on_comboBox_4_activated(int index)
{
    // Affectation de l'adresse I2C carte AN2 Circuit U2
    if (index==0) carteAN2->setAdresseU2(0x14);
    if (index==1) carteAN2->setAdresseU2(0x15);
    if (index==2) carteAN2->setAdresseU2(0x16);
    if (index==3) carteAN2->setAdresseU2(0x17);
    if (index==4) carteAN2->setAdresseU2(0x24);
    if (index==5) carteAN2->setAdresseU2(0x25);
    if (index==6) carteAN2->setAdresseU2(0x26);
    if (index==7) carteAN2->setAdresseU2(0x27);
    if (index==8) carteAN2->setAdresseU2(0x34);
}

void MainWindow::on_comboBox_5_activated(int index)
{
    // Affectation de l'adresse I2C carte AN2 Circuit U3
    if (index==0) carteAN2->setAdresseU3(0x14);
    if (index==1) carteAN2->setAdresseU3(0x15);
    if (index==2) carteAN2->setAdresseU3(0x16);
    if (index==3) carteAN2->setAdresseU3(0x17);
    if (index==4) carteAN2->setAdresseU3(0x24);
    if (index==5) carteAN2->setAdresseU3(0x25);
    if (index==6) carteAN2->setAdresseU3(0x26);
    if (index==7) carteAN2->setAdresseU3(0x27);
    if (index==8) carteAN2->setAdresseU3(0x34);
}

void MainWindow::on_radioButton100_clicked()
{
    this->ui->label_34->setText(" ");
    this->ui->label_33->setText("      ");
    carteAN1->setCH0_5V(false);
    carteAN1->setCH0_10V(false);
    carteAN1->setCH0_4_20mA(false);
}

void MainWindow::on_radioButton_17_clicked()
{
    this->ui->label_34->setText("V");
    carteAN1->setCH0_5V(true);
    carteAN1->setCH0_10V(false);
    carteAN1->setCH0_4_20mA(false);
}

void MainWindow::on_radioButton_18_clicked()
{
    this->ui->label_34->setText("V");
    carteAN1->setCH0_5V(false);
    carteAN1->setCH0_10V(true);
    carteAN1->setCH0_4_20mA(false);
}

void MainWindow::on_radioButton_19_clicked()
{
    this->ui->label_34->setText("mA");
    carteAN1->setCH0_5V(false);
    carteAN1->setCH0_10V(false);
    carteAN1->setCH0_4_20mA(true);
}

void MainWindow::on_radioButton100_9_clicked()
{
    this->ui->label_65->setText(" ");
    this->ui->label_70->setText("      ");
    carteAN2->setCH0_5V(false);
    carteAN2->setCH0_10V(false);
    carteAN2->setCH0_4_20mA(false);
}

void MainWindow::on_radioButton_59_clicked()
{
    this->ui->label_70->setText("V");
    carteAN2->setCH0_5V(true);
    carteAN2->setCH0_10V(false);
    carteAN2->setCH0_4_20mA(false);
}

void MainWindow::on_radioButton_60_clicked()
{
    this->ui->label_70->setText("V");
    carteAN2->setCH0_5V(false);
    carteAN2->setCH0_10V(true);
    carteAN2->setCH0_4_20mA(false);
}

void MainWindow::on_radioButton_61_clicked()
{
    this->ui->label_70->setText("mA");
    carteAN2->setCH0_5V(false);
    carteAN2->setCH0_10V(false);
    carteAN2->setCH0_4_20mA(true);
}





void MainWindow::on_radioButton100_2_clicked()
{
    this->ui->label_37->setText(" ");
    this->ui->label_35->setText("      ");
    carteAN1->setCH1_5V(false);
    carteAN1->setCH1_10V(false);
    carteAN1->setCH1_4_20mA(false);
}

void MainWindow::on_radioButton_20_clicked()
{
    this->ui->label_35->setText("V");
    carteAN1->setCH1_5V(true);
    carteAN1->setCH1_10V(false);
    carteAN1->setCH1_4_20mA(false);
}

void MainWindow::on_radioButton_21_clicked()
{
    this->ui->label_35->setText("V");
    carteAN1->setCH1_5V(false);
    carteAN1->setCH1_10V(true);
    carteAN1->setCH1_4_20mA(false);
}

void MainWindow::on_radioButton_22_clicked()
{
    this->ui->label_35->setText("mA");
    carteAN1->setCH1_5V(false);
    carteAN1->setCH1_10V(false);
    carteAN1->setCH1_4_20mA(true);
}

void MainWindow::on_radioButton100_11_clicked()
{
    this->ui->label_74->setText(" ");
    this->ui->label_76->setText("      ");
    carteAN2->setCH1_5V(false);
    carteAN2->setCH1_10V(false);
    carteAN2->setCH1_4_20mA(false);
}

void MainWindow::on_radioButton_47_clicked()
{
    this->ui->label_76->setText("V");
    carteAN2->setCH1_5V(true);
    carteAN2->setCH1_10V(false);
    carteAN2->setCH1_4_20mA(false);
}

void MainWindow::on_radioButton_48_clicked()
{
    this->ui->label_76->setText("V");
    carteAN2->setCH1_5V(false);
    carteAN2->setCH1_10V(true);
    carteAN2->setCH1_4_20mA(false);
}

void MainWindow::on_radioButton_49_clicked()
{
    this->ui->label_76->setText("mA");
    carteAN2->setCH1_5V(false);
    carteAN2->setCH1_10V(false);
    carteAN2->setCH1_4_20mA(true);
}




void MainWindow::on_radioButton100_3_clicked()
{
    this->ui->label_40->setText(" ");
    this->ui->label_38->setText("      ");
    carteAN1->setCH2_5V(false);
    carteAN1->setCH2_10V(false);
    carteAN1->setCH2_4_20mA(false);
}

void MainWindow::on_radioButton_23_clicked()
{
    this->ui->label_38->setText("V");
    carteAN1->setCH2_5V(true);
    carteAN1->setCH2_10V(false);
    carteAN1->setCH2_4_20mA(false);
}

void MainWindow::on_radioButton_24_clicked()
{
    this->ui->label_38->setText("V");
    carteAN1->setCH2_5V(false);
    carteAN1->setCH2_10V(true);
    carteAN1->setCH2_4_20mA(false);
}

void MainWindow::on_radioButton_25_clicked()
{
    this->ui->label_38->setText("mA");
    carteAN1->setCH2_5V(false);
    carteAN1->setCH2_10V(false);
    carteAN1->setCH2_4_20mA(true);
}

void MainWindow::on_radioButton100_13_clicked()
{
    this->ui->label_56->setText(" ");
    this->ui->label_82->setText("      ");
    carteAN2->setCH2_5V(false);
    carteAN2->setCH2_10V(false);
    carteAN2->setCH2_4_20mA(false);
}

void MainWindow::on_radioButton_50_clicked()
{
    this->ui->label_56->setText("V");
    carteAN2->setCH2_5V(true);
    carteAN2->setCH2_10V(false);
    carteAN2->setCH2_4_20mA(false);
}

void MainWindow::on_radioButton_51_clicked()
{
    this->ui->label_56->setText("V");
    carteAN2->setCH2_5V(false);
    carteAN2->setCH2_10V(true);
    carteAN2->setCH2_4_20mA(false);
}

void MainWindow::on_radioButton_52_clicked()
{
    this->ui->label_56->setText("mA");
    carteAN2->setCH2_5V(false);
    carteAN2->setCH2_10V(false);
    carteAN2->setCH2_4_20mA(true);
}




void MainWindow::on_radioButton100_4_clicked()
{
    this->ui->label_43->setText(" ");
    this->ui->label_41->setText("      ");
    carteAN1->setCH3_5V(false);
    carteAN1->setCH3_10V(false);
    carteAN1->setCH3_4_20mA(false);
}

void MainWindow::on_radioButton_26_clicked()
{
    this->ui->label_41->setText("V");
    carteAN1->setCH3_5V(true);
    carteAN1->setCH3_10V(false);
    carteAN1->setCH3_4_20mA(false);
}

void MainWindow::on_radioButton_27_clicked()
{
    this->ui->label_41->setText("V");
    carteAN1->setCH3_5V(false);
    carteAN1->setCH3_10V(true);
    carteAN1->setCH3_4_20mA(false);
}

void MainWindow::on_radioButton_28_clicked()
{
    this->ui->label_41->setText("mA");
    carteAN1->setCH3_5V(false);
    carteAN1->setCH3_10V(false);
    carteAN1->setCH3_4_20mA(true);
}


void MainWindow::on_radioButton100_15_clicked()
{
    this->ui->label_71->setText(" ");
    this->ui->label_68->setText("      ");
    carteAN2->setCH3_5V(false);
    carteAN2->setCH3_10V(false);
    carteAN2->setCH3_4_20mA(false);
}

void MainWindow::on_radioButton_41_clicked()
{
    this->ui->label_68->setText("V");
    carteAN2->setCH3_5V(true);
    carteAN2->setCH3_10V(false);
    carteAN2->setCH3_4_20mA(false);
}

void MainWindow::on_radioButton_42_clicked()
{
    this->ui->label_68->setText("V");
    carteAN2->setCH3_5V(false);
    carteAN2->setCH3_10V(true);
    carteAN2->setCH3_4_20mA(false);
}

void MainWindow::on_radioButton_43_clicked()
{
    this->ui->label_68->setText("mA");
    carteAN2->setCH3_5V(false);
    carteAN2->setCH3_10V(false);
    carteAN2->setCH3_4_20mA(true);
}





void MainWindow::on_radioButton100_5_clicked()
{
    this->ui->label_52->setText(" ");
    this->ui->label_45->setText("      ");
    carteAN1->setCH4_5V(false);
    carteAN1->setCH4_10V(false);
    carteAN1->setCH4_4_20mA(false);
}

void MainWindow::on_radioButton_35_clicked()
{
    this->ui->label_45->setText("V");
    carteAN1->setCH4_5V(true);
    carteAN1->setCH4_10V(false);
    carteAN1->setCH4_4_20mA(false);
}

void MainWindow::on_radioButton_36_clicked()
{
    this->ui->label_45->setText("V");
    carteAN1->setCH4_5V(false);
    carteAN1->setCH4_10V(true);
    carteAN1->setCH4_4_20mA(false);
}

void MainWindow::on_radioButton_37_clicked()
{
    this->ui->label_45->setText("mA");
    carteAN1->setCH4_5V(false);
    carteAN1->setCH4_10V(false);
    carteAN1->setCH4_4_20mA(true);
}


void MainWindow::on_radioButton100_10_clicked()
{
    this->ui->label_63->setText(" ");
    this->ui->label_61->setText("      ");
    carteAN2->setCH4_5V(false);
    carteAN2->setCH4_10V(false);
    carteAN2->setCH4_4_20mA(false);
}

void MainWindow::on_radioButton_53_clicked()
{
    this->ui->label_61->setText("V");
    carteAN2->setCH4_5V(true);
    carteAN2->setCH4_10V(false);
    carteAN2->setCH4_4_20mA(false);
}

void MainWindow::on_radioButton_54_clicked()
{
    this->ui->label_61->setText("V");
    carteAN2->setCH4_5V(false);
    carteAN2->setCH4_10V(true);
    carteAN2->setCH4_4_20mA(false);
}

void MainWindow::on_radioButton_55_clicked()
{
    this->ui->label_61->setText("mA");
    carteAN2->setCH4_5V(false);
    carteAN2->setCH4_10V(false);
    carteAN2->setCH4_4_20mA(true);
}




void MainWindow::on_radioButton100_6_clicked()
{
    this->ui->label_48->setText(" ");
    this->ui->label_49->setText("      ");
    carteAN1->setCH5_5V(false);
    carteAN1->setCH5_10V(false);
    carteAN1->setCH5_4_20mA(false);
}

void MainWindow::on_radioButton_29_clicked()
{
    this->ui->label_49->setText("V");
    carteAN1->setCH5_5V(true);
    carteAN1->setCH5_10V(false);
    carteAN1->setCH5_4_20mA(false);
}

void MainWindow::on_radioButton_30_clicked()
{
    this->ui->label_49->setText("V");
    carteAN1->setCH5_5V(false);
    carteAN1->setCH5_10V(true);
    carteAN1->setCH5_4_20mA(false);
}

void MainWindow::on_radioButton_31_clicked()
{
    this->ui->label_49->setText("mA");
    carteAN1->setCH5_5V(false);
    carteAN1->setCH5_10V(false);
    carteAN1->setCH5_4_20mA(true);
}

void MainWindow::on_radioButton100_12_clicked()
{
    this->ui->label_69->setText(" ");
    this->ui->label_81->setText("      ");
    carteAN2->setCH5_5V(false);
    carteAN2->setCH5_10V(false);
    carteAN2->setCH5_4_20mA(false);
}

void MainWindow::on_radioButton_56_clicked()
{
    this->ui->label_81->setText("V");
    carteAN2->setCH5_5V(true);
    carteAN2->setCH5_10V(false);
    carteAN2->setCH5_4_20mA(false);
}

void MainWindow::on_radioButton_57_clicked()
{
    this->ui->label_81->setText("V");
    carteAN2->setCH5_5V(false);
    carteAN2->setCH5_10V(true);
    carteAN2->setCH5_4_20mA(false);
}

void MainWindow::on_radioButton_58_clicked()
{
    this->ui->label_81->setText("mA");
    carteAN2->setCH5_5V(false);
    carteAN2->setCH5_10V(false);
    carteAN2->setCH5_4_20mA(true);
}





void MainWindow::on_radioButton100_7_clicked()
{
    this->ui->label_54->setText(" ");
    this->ui->label_50->setText("      ");
    carteAN1->setCH6_5V(false);
    carteAN1->setCH6_10V(false);
    carteAN1->setCH6_4_20mA(false);
}

void MainWindow::on_radioButton_32_clicked()
{
    this->ui->label_50->setText("V");
    carteAN1->setCH6_5V(true);
    carteAN1->setCH6_10V(false);
    carteAN1->setCH6_4_20mA(false);
}

void MainWindow::on_radioButton_33_clicked()
{
    this->ui->label_50->setText("V");
    carteAN1->setCH6_5V(false);
    carteAN1->setCH6_10V(true);
    carteAN1->setCH6_4_20mA(false);
}

void MainWindow::on_radioButton_34_clicked()
{
    this->ui->label_50->setText("mA");
    carteAN1->setCH6_5V(false);
    carteAN1->setCH6_10V(false);
    carteAN1->setCH6_4_20mA(true);
}

void MainWindow::on_radioButton100_14_clicked()
{
    this->ui->label_64->setText(" ");
    this->ui->label_75->setText("      ");
    carteAN2->setCH6_5V(false);
    carteAN2->setCH6_10V(false);
    carteAN2->setCH6_4_20mA(false);
}

void MainWindow::on_radioButton_62_clicked()
{
    this->ui->label_75->setText("V");
    carteAN2->setCH6_5V(true);
    carteAN2->setCH6_10V(false);
    carteAN2->setCH6_4_20mA(false);
}

void MainWindow::on_radioButton_63_clicked()
{
    this->ui->label_75->setText("V");
    carteAN2->setCH6_5V(false);
    carteAN2->setCH6_10V(true);
    carteAN2->setCH6_4_20mA(false);
}

void MainWindow::on_radioButton_64_clicked()
{
    this->ui->label_75->setText("mA");
    carteAN2->setCH6_5V(false);
    carteAN2->setCH6_10V(false);
    carteAN2->setCH6_4_20mA(true);
}





void MainWindow::on_radioButton100_8_clicked()
{
    this->ui->label_44->setText(" ");
    this->ui->label_47->setText("      ");
    carteAN1->setCH7_5V(false);
    carteAN1->setCH7_10V(false);
    carteAN1->setCH7_4_20mA(false);
}

void MainWindow::on_radioButton_38_clicked()
{
    this->ui->label_47->setText("V");
    carteAN1->setCH7_5V(true);
    carteAN1->setCH7_10V(false);
    carteAN1->setCH7_4_20mA(false);
}

void MainWindow::on_radioButton_39_clicked()
{
    this->ui->label_47->setText("V");
    carteAN1->setCH7_5V(false);
    carteAN1->setCH7_10V(true);
    carteAN1->setCH7_4_20mA(false);
}

void MainWindow::on_radioButton_40_clicked()
{
    this->ui->label_47->setText("mA");
    carteAN1->setCH7_5V(false);
    carteAN1->setCH7_10V(false);
    carteAN1->setCH7_4_20mA(true);
}

void MainWindow::on_radioButton100_16_clicked()
{
    this->ui->label_60->setText(" ");
    this->ui->label_78->setText("      ");
    carteAN2->setCH7_5V(false);
    carteAN2->setCH7_10V(false);
    carteAN2->setCH7_4_20mA(false);
}

void MainWindow::on_radioButton_44_clicked()
{
    this->ui->label_78->setText("V");
    carteAN2->setCH7_5V(true);
    carteAN2->setCH7_10V(false);
    carteAN2->setCH7_4_20mA(false);
}

void MainWindow::on_radioButton_45_clicked()
{
    this->ui->label_78->setText("V");
    carteAN2->setCH7_5V(false);
    carteAN2->setCH7_10V(true);
    carteAN2->setCH7_4_20mA(false);
}

void MainWindow::on_radioButton_46_clicked()
{
    this->ui->label_78->setText("mA");
    carteAN2->setCH7_5V(false);
    carteAN2->setCH7_10V(false);
    carteAN2->setCH7_4_20mA(true);
}
